#!/bin/sh
#
# Code common to all package actions.
#
# Copyright 2023 Andrew Wood
#
# License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
#

packageManagerType=""
packageManagerCommand=""

# Set the "packageManagerType" variable to the function prefix for the
# package manager that is in use on this system, and "packageManagerCommand"
# to the name of the main command, or report an error if no supported
# package manager was found (and return 2).
#
actIdentifyPackageManager () {
	if command -v apt-get >/dev/null 2>&1; then
		packageManagerType="debian"
		packageManagerCommand="apt-get"
	elif command -v zypper >/dev/null 2>&1; then
		packageManagerType="suse"
		packageManagerCommand="zypper"
	elif command -v dnf >/dev/null 2>&1; then
		packageManagerType="redhat"
		packageManagerCommand="dnf"
	elif command -v yum >/dev/null 2>&1; then
		packageManagerType="redhat"
		packageManagerCommand="yum"
	elif command -v pkg_add >/dev/null 2>&1; then
		packageManagerType="openbsd"
		packageManagerCommand="pkg_add"
	elif command -v pkg >/dev/null 2>&1; then
		packageManagerType="freebsd"
		packageManagerCommand="pkg"
	else
		actError "NO-PACKAGE-MANAGER"
		return 2
	fi
	actDebug "packageManagerType=[${packageManagerType}], packageManagerCommand=[${packageManagerCommand}]"
	return 0
}

# Sanitise the given list of package names to strip those containing / or ;
# characters, and any starting with "-".
#
actSanitisePackageList () {
	echo "$*" | tr ' \t' '\n\n' | grep -Ev -e '^-' -e '/' -e ';' | tr -s '\n' | tr '\n' ' ' | sed 's/ $//'
}

# Catch-all for all package actions.  Load the code appropriate to the
# package manager, run its action class function, and override the action
# function.
#
actPackage () {
	actIdentifyPackageManager
	subReturnCode=$?
	test "${subReturnCode}" -eq 0 || return "${subReturnCode}"

	# Load the appropriate overrides for the package type.
	actOverrideClass "${packageManagerType}" "$@"
	subReturnCode=$?
	test "${subReturnCode}" -eq 0 || return "${subReturnCode}"

	return 0
}
