#!/bin/sh
#
# Code common to all service actions.
#
# Copyright 2023 Andrew Wood
#
# License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
#

serviceManagerType=""
serviceManagerVariant=""

# Set the "serviceManagerType" variable to the function prefix for the
# service manager that is in use on this system, and "serviceManagerVariant"
# to the variant if applicable, such as "redhat" vs "debian" for the
# "sysvinit" type, or report an error if no supported service manager was
# found (and return 2).
#
actIdentifyServiceManager () {
	if command -v systemctl >/dev/null 2>&1; then
		serviceManagerType="systemd"
		serviceManagerVariant=""
	elif command -v service >/dev/null 2>&1 && command -v update-rc.d >/dev/null 2>&1; then
		serviceManagerType="sysvinit"
		serviceManagerVariant="debian"
	elif command -v service >/dev/null 2>&1 && command -v chkconfig >/dev/null 2>&1; then
		serviceManagerType="sysvinit"
		serviceManagerVariant="redhat"
	else
		actError "NO-SERVICE-MANAGER"
		return 2
	fi
	actDebug "serviceManagerType=[${serviceManagerType}], serviceManagerVariant=[${serviceManagerVariant}]"
	return 0
}


actService () {
	actIdentifyServiceManager
	subReturnCode=$?
	test "${subReturnCode}" -eq 0 || return "${subReturnCode}"

	# Load the appropriate overrides for the service type.
	actOverrideClass "${serviceManagerType}" "$@"
	subReturnCode=$?
	test "${subReturnCode}" -eq 0 || return "${subReturnCode}"

	return 0
}
